<div class="<?php echo is_admin() ? 'tutor-option-single-item' : ''; ?> tutor-cb-templates-table">

	<?php 
		$per_page = 15;
		$current_page = max( 1, tutor_utils()->avalue_dot('current_page', $_GET) );
		$utils_object = new Tutor\Certificate\Builder\Utils;
		$author_id = tutor_utils()->has_user_role('administrator') ? null : get_current_user_id();
		$certificates = $utils_object->get_certificates($current_page, $per_page, $author_id, array('publish', 'pending', 'draft'));
		$certificates_total = $utils_object->get_certificates(0, -1, $author_id, array('publish', 'pending', 'draft'), true);

		// Load head section if frontend
		// Admin side has different layout for it
		if(!is_admin()) {
			require __DIR__ . '/add-certificate-area.php';
		}
	?>

	<?php if(!is_admin()): ?>
		<div class="color-text-subsued tutor-text-regular-body tutor-mb-16">
			<?php _e('All Certificates', 'tutor-lms-certificate-builder'); ?>
		</div>
	<?php endif; ?>

	<table class="tutor-ui-table tutor-ui-table-responsive tutor-no-thead tutor-bg-white tutor-ui-table-certificate-settings">
		<tbody>
			<?php foreach($certificates as $certificate): ?>
				<?php 
					$row_id = 'tutor-cb-row-id-' . $certificate->ID; 
					$delete_id = 'tutor-cb-row-del-' . $certificate->ID; 
				?>
				<tr id="<?php echo $row_id; ?>">
					<td data-th="Certificate" class="column-fullwidth">
						<div class="td-course text-medium-body color-text-primary">
							<div class="tutor-row tutor-align-items-center">
								<?php 
									if($certificate->thumbnail_url) {
										?>
										<div class="tutor-col-auto">
											<img style="width:90px; height:auto;" src="<?php echo esc_url($certificate->thumbnail_url); ?>"/>
										</div>
										<?php
									}
								?>
								<div class="tutor-col">
									<span class="td-course text-medium-body color-text-primary tutor-d-block">
										<?php esc_html_e( $certificate->post_title ); ?>
									</span>
								</div>
							</div>
						</div>
					</td>
					<td data-th="Action">
						<div class="tutor-option-field-input d-flex has-btn-after tutor-justify-content-end">
							<div class="tutor-form-select-with-icon <?php echo $certificate->post_status=='draft' ? 'select-default' : 'select-success'; ?>">
								<select class="tutor-cb-status tutor-table-row-status-update" title="<?php _e('Set certificate template status', 'tutor-lms-certificate-builder'); ?>" data-status_key="status" data-template_id="<?php echo $certificate->ID; ?>" data-action="tutor_cb_template_status_update">
									<option data-status_class="select-default" value="draft" <?php selected($certificate->post_status, 'draft'); ?>>
										<?php _e('Draft', 'tutor-lms-certificate-builder'); ?>
									</option>
									<option data-status_class="select-success" value="publish" <?php selected($certificate->post_status, 'publish'); ?>>
										<?php _e('Published', 'tutor-lms-certificate-builder'); ?>
									</option>
								</select>
								<i class="icon1 tutor-icon-eye-fill-filled"></i>
								<i class="icon2 tutor-icon-angle-down-filled"></i>
							</div>
							<a href="<?php echo $certificate->edit_url; ?>" class=" tutor-ml-16">
								<i class="tutor-icon-edit-filled color-black-40 tutor-icon-24"></i>
							</a>
							<span data-tutor-modal-target="<?php echo $delete_id; ?>" class="tutor-ml-12">
								<i class="tutor-icon-delete-stroke-filled color-black-40 tutor-icon-24"></i>
							</span>
						</div>

						<!-- Delete Modal -->
						<div id="<?php echo $delete_id; ?>" class="tutor-modal">
							<span class="tutor-modal-overlay"></span>
							<button data-tutor-modal-close class="tutor-modal-close">
								<span class="las la-times"></span>
							</button>
							<div class="tutor-modal-root">
								<div class="tutor-modal-inner">
									<div class="tutor-modal-body tutor-text-center">
										<div class="tutor-modal-icon">
											<img src="<?php echo tutor()->url; ?>assets/images/icon-trash.svg" />
										</div>
										<div class="tutor-modal-text-wrap">
											<h3 class="tutor-modal-title">
												<?php esc_html_e('Delete This Certificate?', 'tutor-lms-certificate-builder'); ?>
											</h3>
											<p>
												<?php esc_html_e('Are you sure you want to delete this certificate permanently from the site? Please confirm your choice.', 'tutor-lms-certificate-builder'); ?>
											</p>
										</div>
										<div class="tutor-modal-btns tutor-btn-group">
											<button data-tutor-modal-close class="tutor-btn tutor-is-outline tutor-is-default">
												<?php esc_html_e('Cancel', 'tutor-lms-certificate-builder'); ?>
											</button>
											<button class="tutor-btn tutor-list-ajax-action" data-request_data='{"certificate_id":<?php echo $certificate->ID;?>,"action":"tutor_delete_certificate_template"}' data-delete_element_id="<?php echo $row_id; ?>">
												<?php esc_html_e('Yes, Delete This', 'tutor-lms-certificate-builder'); ?>
											</button>
										</div>
									</div>
								</div>
							</div>
						</div>
					</td>
				</tr>
			<?php endforeach; ?>

			<?php if(empty($certificates)): ?>
				<td colspan="100%">
					<?php tutor_utils()->tutor_empty_state( __('No certificate!', 'tutor-lms-certificate-builder') ); ?>
				</td>
			<?php endif; ?>
		</tbody>
	</table>

	<div class="tutor-admin-page-pagination-wrapper tutor-mt-25">
		<?php
			/**
			 * Prepare pagination data & load template
			 */
			if($certificates_total > $per_page) {
				$pagination_data     = array(
					'base'		  => '?current_page=%#%',
					'total_items' => $certificates_total,
					'per_page'    => $per_page,
					'paged'       => $current_page,
				);
				$pagination_template = tutor()->path . 'views/elements/pagination.php';
				tutor_load_template_from_custom_path( $pagination_template, $pagination_data );
			}
		?>
	</div>
</div>

